(cl:load (cl:merge-pathnames "../pcre/preload.lisp" cl:*load-truename*))
(sys::dynload-modules (cl:merge-pathnames "lib-pcre.dll" cl:*load-truename*) (quote ( "pcre" )))
(ext:appease-cerrors ; for DEF-CALL-OUT to non-existent functions
 (cl:load (cl:merge-pathnames "../pcre/pcre.fas" cl:*load-truename*))
)
