IMPORTS
	lisp.exe.time_t_from_filetime
	lisp.exe.time_t_to_filetime
	lisp.exe.fd_read
	lisp.exe.fd_write
	lisp.exe.OS_error
	lisp.exe.OS_error
	lisp.exe.inside_gc
	lisp.exe.convert_time_to_universal
	lisp.exe.convert_time_from_universal
	lisp.exe.STACK
	lisp.exe.error_notreached
	lisp.exe.clgettext
	lisp.exe.CLSTEXT
	lisp.exe.object_out
	lisp.exe.allocate_cons
	lisp.exe.allocate_vector
	lisp.exe.allocate_bit_vector
	lisp.exe.allocate_s32string
	lisp.exe.allocate_fpointer
	lisp.exe.clisp_malloc
	lisp.exe.clisp_realloc
	lisp.exe.begin_want_sigcld
	lisp.exe.end_want_sigcld
	lisp.exe.writing_to_subprocess
	lisp.exe.subr_tab_data
	lisp.exe.symbol_tab_data
	lisp.exe.object_tab
	lisp.exe.module_count
	lisp.exe.add_module
	lisp.exe.mv_count
	lisp.exe.mv_space
	lisp.exe.back_trace
	lisp.exe.funcall
	lisp.exe.n_char_to_string
	lisp.exe.asciz_to_string
	lisp.exe.ascii_to_string
	lisp.exe.string_to_asciz
	lisp.exe.data_to_sbvector
	lisp.exe.vector_length
	lisp.exe.vectorof
	lisp.exe.array_displace_check
	lisp.exe.error_nilarray_retrieve
	lisp.exe.array_atype
	lisp.exe.array_rank
	lisp.exe.get_array_dimensions
	lisp.exe.copy_8bit_16bit
	lisp.exe.copy_8bit_32bit
	lisp.exe.copy_16bit_8bit
	lisp.exe.copy_16bit_16bit
	lisp.exe.copy_16bit_32bit
	lisp.exe.copy_32bit_8bit
	lisp.exe.copy_32bit_16bit
	lisp.exe.unpack_string_ro
	lisp.exe.string_equal
	lisp.exe.test_vector_limits
	lisp.exe.string_concat
	lisp.exe.gethash
	lisp.exe.copy_list
	lisp.exe.llength1
	lisp.exe.nreverse
	lisp.exe.deleteq
	lisp.exe.endp
	lisp.exe.listof
	lisp.exe.memq
	lisp.exe.map_lisp_to_c
	lisp.exe.map_c_to_lisp
	lisp.exe.map_c_to_list
	lisp.exe.map_list_to_c
	lisp.exe.push_string_array
	lisp.exe.safe_to_string
	lisp.exe.error
	lisp.exe.check_value
	lisp.exe.OS_error_arg
	lisp.exe.OS_filestream_error
	lisp.exe.check_classname
	lisp.exe.check_fpointer_replacement
	lisp.exe.check_list_replacement
	lisp.exe.error_proper_list_dotted
	lisp.exe.check_array_replacement
	lisp.exe.check_vector_replacement
	lisp.exe.check_byte_vector_replacement
	lisp.exe.check_posfixnum_replacement
	lisp.exe.check_pos_integer_replacement
	lisp.exe.check_string_replacement
	lisp.exe.error_string_integer
	lisp.exe.error_plist_odd
	lisp.exe.error_key_odd
	lisp.exe.error_key_badkw
	lisp.exe.error_c_integer
	lisp.exe.check_c_integer_replacement
	lisp.exe.check_uint_replacement
	lisp.exe.check_sint_replacement
	lisp.exe.check_ulong_replacement
	lisp.exe.check_slong_replacement
	lisp.exe.check_ffloat_replacement
	lisp.exe.check_dfloat_replacement
	lisp.exe.find_package
	lisp.exe.intern
	lisp.exe.intern_keyword
	lisp.exe.physical_namestring
	lisp.exe.pathname_to_OSdir
	lisp.exe.OSdir_to_pathname
	lisp.exe.handle_dup
	lisp.exe.handle_dup2
	lisp.exe.check_direction
	lisp.exe.check_if_does_not_exist
	lisp.exe.if_does_not_exist_symbol
	lisp.exe.check_if_exists
	lisp.exe.if_exists_symbol
	lisp.exe.typep_class
	lisp.exe.typep_classname
	lisp.exe.map_sequence
	lisp.exe.sec_usec
	lisp.exe.sec_usec_number
	lisp.exe.builtin_stream_close
	lisp.exe.stream_lend_handle
	lisp.exe.open_file_stream_handle
	lisp.exe.handle_length
	lisp.exe.read_byte_array
	lisp.exe.write_byte_array
	lisp.exe.file_stream_truename
	lisp.exe.make_file_stream
	lisp.exe.stream_handles
	lisp.exe.addr_to_string
	lisp.exe.string_to_addr
	lisp.exe.resolve_host
	lisp.exe.L_to_I
	lisp.exe.Q_to_I
	lisp.exe.UQ_to_I
	lisp.exe.I_to_UL
	lisp.exe.I_to_L
	lisp.exe.I_to_UQ
	lisp.exe.I_to_Q
	lisp.exe.UDS_to_I
	lisp.exe.DS_to_I
	lisp.exe.I_integer_length
	lisp.exe.LEbytes_to_UI
	lisp.exe.LEbytes_to_I
	lisp.exe.UI_to_LEbytes
	lisp.exe.I_to_LEbytes
	lisp.exe.c_float_to_FF
	lisp.exe.FF_to_c_float
	lisp.exe.c_double_to_DF
	lisp.exe.DF_to_c_double
	lisp.exe.to_double
	lisp.exe.to_int
	lisp.exe.hostent_to_lisp
