(cl:load (cl:merge-pathnames "../clx/new-clx/clx-preload.lisp" cl:*load-truename*))
(sys::dynload-modules (cl:merge-pathnames "lib-clx.dll" cl:*load-truename*) (quote ( "clx" )))
(ext:appease-cerrors ; for DEF-CALL-OUT to non-existent functions
 (cl:load (cl:merge-pathnames "../clx/new-clx/clx.fas" cl:*load-truename*))
 (cl:load (cl:merge-pathnames "../clx/new-clx/image.fas" cl:*load-truename*))
 (cl:load (cl:merge-pathnames "../clx/new-clx/resource.fas" cl:*load-truename*))
)
